package Bundle::LawMonkey;

$VERSION = '0.01'
1;
_END_
=head1 Name
Bundle::LawMonkey --Bundle for MSV's SpamAssassin install
=head1 SYNOPSIS
C<perl -MCPAN -e 'install Bundle::LawMonkey'>

=head1 ABSTRACT

  This should be the abstract for Bundle::MNPBundle.
  The abstract is used when making PPD (Perl Package Description) files.
  If you don't want an ABSTRACT you should also edit Makefile.PL to
  remove the ABSTRACT_FROM option.

=head1 CONTENTS
MD5
LWP
Mail::Internet
Archive::Tar
Archive::Zip
IO::Wrap
IO::Stringy
Unix::Syslog
MIME::Words
MIME::Head
MIME::Body
MIME::Entity
MIME::Parser
Net::SMTP
Net::DNS
Net::Ping
Net::Server
Net::Server::PreForkSimple
Convert::TNEF
Convert::UUlib
MIME::Decoder::Base64
MIME::Decoder::Binary
MIME::Decoder::Gzip64
MIME::Decoder::NBit
MIME::Decoder::QuotedPrint
MIME::Decoder::UU
Time::HiRes
Digest::SHA1
Digest::Nilsimsa
Getopt::Long
File::Copy
Bit::Vector
Date::Calc
Mail::SpamAssassin

=head1 DESCRIPTION
These modules are required per SVM's installation instructions. Creating a bundle just makes it a bit quicker.
=head1 AUTHOR
Mike Prunty  mnpjr@mac.com
=head1 LINCENSE
Use this!
=head1 SEE ALSO
perl(1).

=cut
